@@ -1,13 +1,13 @@
 package Sah::Schema::perl::distname;
 
-our $DATE = '2016-07-17'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-07-20'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name',
     match => '\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\z',
     'x.perl.coerce_rules' => [
-        'str',
+        'str_normalize_perl_distname',
     ],
 }, {}];
 
@@ -26,7 +26,7 @@ Sah::Schema::perl::distname - Perl distribution name
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2016-07-17.
+This document describes version 0.002 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2016-07-20.
 
 =head1 HOMEPAGE
 
